@@ -28,17 +28,16 @@
 #include <sched.h>
 #include <errno.h>
 #include <debug.h>
+#include <unistd.h>
 
 #include <net/if.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
 
-#include <nuttx/net/arp.h>
 #include "netutils/netlib.h"
 
 #if defined(CONFIG_EXAMPLES_BRIDGE_NET1_DHCPC) || \
     defined(CONFIG_EXAMPLES_BRIDGE_NET2_DHCPC)
-#  include <arpa/inet.h>
 #  include "netutils/dhcpc.h"
 #endif
 
