@@ -35,6 +35,17 @@
 
 #include "industry/foc/foc_common.h"
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+#ifndef CONFIG_EXAMPLES_FOC_FLOAT_INST
+#  define CONFIG_EXAMPLES_FOC_FLOAT_INST   (0)
+#endif
+#ifndef CONFIG_EXAMPLES_FOC_FIXED16_INST
+#  define CONFIG_EXAMPLES_FOC_FIXED16_INST (0)
+#endif
+
 /****************************************************************************
  * Extern Functions Prototypes
  ****************************************************************************/
@@ -53,6 +64,7 @@ extern int foc_fixed16_thr(FAR struct foc_ctrl_env_s *envp);
 
 pthread_mutex_t g_cntr_lock;
 
+static uint32_t g_foc_thr = 0;
 #ifdef CONFIG_INDUSTRY_FOC_FLOAT
 static int g_float_thr_cntr = 0;
 #endif
@@ -79,35 +91,19 @@ static FAR void *foc_control_thr(FAR void *arg)
 
   /* Get controller type */
 
-  pthread_mutex_lock(&g_cntr_lock);
-
-#ifdef CONFIG_INDUSTRY_FOC_FLOAT
-  if (g_float_thr_cntr < CONFIG_EXAMPLES_FOC_FLOAT_INST)
-    {
-      envp->type = FOC_NUMBER_TYPE_FLOAT;
-    }
-  else
-#endif
-#ifdef CONFIG_INDUSTRY_FOC_FIXED16
-  if (g_fixed16_thr_cntr < CONFIG_EXAMPLES_FOC_FIXED16_INST)
-    {
-      envp->type = FOC_NUMBER_TYPE_FIXED16;
-    }
-  else
-#endif
+  envp->type = foc_thread_type(envp->id);
+  if (envp->type == -1)
     {
       /* Invalid configuration */
 
       ASSERT(0);
     }
 
-  pthread_mutex_unlock(&g_cntr_lock);
-
   PRINTF("FOC device %d type = %d!\n", envp->id, envp->type);
 
   /* Get queue name */
 
-  sprintf(mqname, "%s%d", CONTROL_MQ_MQNAME, envp->id);
+  snprintf(mqname, sizeof(mqname), "%s%d", CONTROL_MQ_MQNAME, envp->id);
 
   /* Open queue */
 
@@ -148,6 +144,7 @@ static FAR void *foc_control_thr(FAR void *arg)
           pthread_mutex_lock(&g_cntr_lock);
           envp->inst = g_float_thr_cntr;
           g_float_thr_cntr += 1;
+          g_foc_thr |= (1 << envp->id);
           pthread_mutex_unlock(&g_cntr_lock);
 
           /* Start thread */
@@ -156,6 +153,7 @@ static FAR void *foc_control_thr(FAR void *arg)
 
           pthread_mutex_lock(&g_cntr_lock);
           g_float_thr_cntr -= 1;
+          g_foc_thr &= ~(1 << envp->id);
           pthread_mutex_unlock(&g_cntr_lock);
 
           break;
@@ -168,6 +166,7 @@ static FAR void *foc_control_thr(FAR void *arg)
           pthread_mutex_lock(&g_cntr_lock);
           envp->inst = g_fixed16_thr_cntr;
           g_fixed16_thr_cntr += 1;
+          g_foc_thr |= (1 << envp->id);
           pthread_mutex_unlock(&g_cntr_lock);
 
           /* Start thread */
@@ -176,6 +175,7 @@ static FAR void *foc_control_thr(FAR void *arg)
 
           pthread_mutex_lock(&g_cntr_lock);
           g_fixed16_thr_cntr -= 1;
+          g_foc_thr &= ~(1 << envp->id);
           pthread_mutex_unlock(&g_cntr_lock);
 
           break;
@@ -251,21 +251,54 @@ bool foc_threads_terminated(void)
 {
   bool ret = false;
 
-  pthread_mutex_unlock(&g_cntr_lock);
+  pthread_mutex_lock(&g_cntr_lock);
 
-  if (1
-#ifdef CONFIG_INDUSTRY_FOC_FLOAT
-      && g_float_thr_cntr <= 0
-#endif
-#ifdef CONFIG_INDUSTRY_FOC_FIXED16
-      && g_fixed16_thr_cntr <= 0
-#endif
-    )
+  if (g_foc_thr == 0)
     {
       ret = true;
     }
 
+  pthread_mutex_unlock(&g_cntr_lock);
+
+  return ret;
+}
+
+/****************************************************************************
+ * Name: foc_threads_get
+ ****************************************************************************/
+
+uint32_t foc_threads_get(void)
+{
+  uint32_t ret = 0;
+
   pthread_mutex_lock(&g_cntr_lock);
+  ret = g_foc_thr;
+  pthread_mutex_unlock(&g_cntr_lock);
+
+  return ret;
+}
+
+/****************************************************************************
+ * Name: foc_thread_type
+ ****************************************************************************/
+
+int foc_thread_type(int id)
+{
+  int ret = -1;
+
+#ifdef CONFIG_INDUSTRY_FOC_FLOAT
+  if (id < CONFIG_EXAMPLES_FOC_FLOAT_INST)
+    {
+      ret = FOC_NUMBER_TYPE_FLOAT;
+    }
+#endif
+
+#ifdef CONFIG_INDUSTRY_FOC_FIXED16
+  if (id < CONFIG_EXAMPLES_FOC_FLOAT_INST + CONFIG_EXAMPLES_FOC_FIXED16_INST)
+    {
+      ret = FOC_NUMBER_TYPE_FIXED16;
+    }
+#endif
 
   return ret;
 }
@@ -299,7 +332,7 @@ int foc_ctrlthr_init(FAR struct foc_ctrl_env_s *foc, int i, FAR mqd_t *mqd,
 
   /* Get queue name */
 
-  sprintf(mqname, "%s%d", CONTROL_MQ_MQNAME, foc->id);
+  snprintf(mqname, sizeof(mqname), "%s%d", CONTROL_MQ_MQNAME, foc->id);
 
   /* Initialize thread recv queue */
 
