@@ -92,8 +92,9 @@ static char *padstr(char *s, int length)
   static char buf[MAXSTRLEN];
   char fmt[10];
 
-  sprintf(fmt, (int)strlen(s) > length ? "%%.%ds" : "%%-%ds", length);
-  sprintf(buf, fmt, s);
+  snprintf(fmt, sizeof(fmt),
+           (int)strlen(s) > length ? "%%.%ds" : "%%-%ds", length);
+  snprintf(buf, sizeof(buf), fmt, s);
 
   return buf;
 }
@@ -206,7 +207,7 @@ static void idle(void)
     }
 
   tp = localtime(&t);
-  sprintf(buf, " %.2d-%.2d-%.4d  %.2d:%.2d:%.2d",
+  snprintf(buf, sizeof(buf), " %.2d-%.2d-%.4d  %.2d:%.2d:%.2d",
           tp->tm_mday, tp->tm_mon + 1, tp->tm_year + 1900,
           tp->tm_hour, tp->tm_min, tp->tm_sec);
 
