@@ -22,7 +22,6 @@
 #define _TOYWASM_CONFIG_H
 
 #define TOYWASM_USE_SEPARATE_EXECUTE
-#define TOYWASM_USE_TAILCALL
 #define TOYWASM_USE_JUMP_BINARY_SEARCH
 #define TOYWASM_JUMP_CACHE2_SIZE 4
 #define TOYWASM_USE_LOCALS_CACHE
@@ -31,6 +30,7 @@
 #define TOYWASM_USE_RESULTTYPE_CELLIDX
 #define TOYWASM_USE_LOCALTYPE_CELLIDX
 #define TOYWASM_ENABLE_WRITER
+#define TOYWASM_ENABLE_WASM_SIMD
 #define TOYWASM_ENABLE_WASM_EXTENDED_CONST
 #define TOYWASM_ENABLE_WASM_MULTI_MEMORY
 #define TOYWASM_ENABLE_WASM_TAILCALL
