@@ -28,7 +28,8 @@
 
 const char *toywasm_config_string =
 "\tTOYWASM_USE_SEPARATE_EXECUTE = ON\n"
-"\tTOYWASM_USE_TAILCALL = ON\n"
+"\tTOYWASM_USE_TAILCALL = OFF\n"
+"\tTOYWASM_USE_SIMD = OFF\n"
 "\tTOYWASM_USE_SHORT_ENUMS = OFF\n"
 "\tTOYWASM_USE_USER_SCHED = OFF\n"
 "\tTOYWASM_ENABLE_TRACING = OFF\n"
@@ -41,7 +42,9 @@ const char *toywasm_config_string =
 "\tTOYWASM_USE_SMALL_CELLS = ON\n"
 "\tTOYWASM_USE_RESULTTYPE_CELLIDX = ON\n"
 "\tTOYWASM_USE_LOCALTYPE_CELLIDX = ON\n"
+"\tTOYWASM_PREALLOC_SHARED_MEMORY = OFF\n"
 "\tTOYWASM_ENABLE_WRITER = ON\n"
+"\tTOYWASM_ENABLE_WASM_SIMD = ON\n"
 "\tTOYWASM_ENABLE_WASM_EXTENDED_CONST = ON\n"
 "\tTOYWASM_ENABLE_WASM_MULTI_MEMORY = ON\n"
 "\tTOYWASM_ENABLE_WASM_TAILCALL = ON\n"
