@@ -204,7 +204,7 @@ static void show_environment(bool var1_valid, bool var2_valid,
   show_variable(g_var3_name, g_var3_value, var3_valid);
 }
 #else
-# define show_environment()
+#  define show_environment()
 #endif
 
 /****************************************************************************
@@ -451,7 +451,7 @@ static int user_main(int argc, char *argv[])
       pthread_rwlock_cancel_test();
       check_test_memory_usage();
 
-#ifdef CONFIG_PTHREAD_CLEANUP
+#if defined(CONFIG_PTHREAD_CLEANUP_STACKSIZE) && CONFIG_PTHREAD_CLEANUP_STACKSIZE > 0
       /* Verify pthread cancellation cleanup handlers */
 
       printf("\nuser_main: pthread_cleanup test\n");
