@@ -42,6 +42,7 @@
 #include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <unistd.h>
 #include <sys/ioctl.h>
 #include <arpa/inet.h>
 
@@ -591,7 +592,7 @@ static int i8sak_setup(FAR struct i8sak_s *i8sak, FAR const char *ifname)
       return ERROR;
     }
 
-  strcpy(&i8sak->ifname[0], ifname);
+  strlcpy(i8sak->ifname, ifname, sizeof(i8sak->ifname));
 
   i8sak->chan = 11;
   i8sak->chpage = 0;
@@ -681,10 +682,8 @@ static int i8sak_setup(FAR struct i8sak_s *i8sak, FAR const char *ifname)
   sem_init(&i8sak->exclsem, 0, 1);
 
   sem_init(&i8sak->updatesem, 0, 0);
-  sem_setprotocol(&i8sak->updatesem, SEM_PRIO_NONE);
 
   sem_init(&i8sak->sigsem, 0, 0);
-  sem_setprotocol(&i8sak->sigsem, SEM_PRIO_NONE);
 
   sem_init(&i8sak->eventsem, 0, 1);
 
